@@ -390,18 +390,19 @@ class RestAPI(object):
 
 		# iterate users.
 		# do by firestore because new users are missed by firebase iteration for a few minutes.
-		firebase_users = self.firebase.users.iterate()
+		#firebase_users = self.firebase.users.iterate()
 		firestore_users = self.firebase.users.iterate(by_firestore=True)
-		_users_, _user_emails_ = [], []
-		for l_users in [firestore_users, firebase_users]:
-			for user in l_users:
-				if user.email not in _user_emails_: 
-					_users_.append(user)
-					_user_emails_.append(user.email)
-		for user in _users_: 
+		#_users_, _user_emails_ = [], []
+		#for l_users in [firestore_users, firebase_users]:
+		#	for user in l_users:
+		#		if user.email not in _user_emails_: 
+		#			_users_.append(user)
+		#			_user_emails_.append(user.email)
+		#for user in _users_: 
+		for email in firestore_users:
 
 			# load data.
-			uid = user.email # <-- NOTE THE CHANGE OF SAVING USERS BY (email) INSTEAD OF BY (uid).
+			uid = email #user.email # <-- NOTE THE CHANGE OF SAVING USERS BY (email) INSTEAD OF BY (uid).
 			reference = f"users/{uid}"
 			response = self.firebase.firestore.load(reference)
 
